/*
 *   @file  osal_MemoryP.c
 *
 *   @brief
 *          This file implements the TI-RTOS version of Memory Allocation Functionality
 *
 *  \par
 *  NOTE:
 *      (C) Copyright 2020 Texas Instruments, Inc.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
 *  ======== MemoryP_tirtos.c ========
 */
#include "osal/MemoryP.h"

#include <stdint.h>
#include <stdbool.h>
#include <stdlib.h>

#include <xdc/std.h>
#include <xdc/runtime/Error.h>
#include <xdc/runtime/Memory.h>

/*
 *  ======== MemoryP_ctrlAlloc ========
 */
void* MemoryP_ctrlAlloc(uint32_t size, uint8_t alignment)
{
    /* Allocate memory from the default heap for the control memory:
     * One possible use case is to use seperate heaps for the data
     * and control operations. */
    return Memory_alloc (NULL, size, alignment, NULL);
}

/*
 *  ======== MemoryP_ctrlFree ========
 */
void MemoryP_ctrlFree(void* ptr, uint32_t size)
{
    /* Free the memory to the appropriate heap: */
    Memory_free(NULL, ptr, size);
}

/*
 *  ======== MemoryP_dataAlloc ========
 */
void* MemoryP_dataAlloc(uint32_t size, uint8_t alignment)
{
    /* Allocate memory from the default heap for the data memory:
     * One possible use case is to use seperate heaps for the data
     * and control operations. */
    return Memory_alloc (NULL, size, alignment, NULL);
}

/*
 *  ======== MemoryP_dataFree ========
 */
void MemoryP_dataFree(void* ptr, uint32_t size)
{
    /* Free the memory to the appropriate heap: */
    Memory_free(NULL, ptr, size);
}

/*
 *  ======== MemoryP_getStats ========
 */
void MemoryP_getStats(MemoryP_Stats *stats)
{
    Memory_getStats(NULL, (Memory_Stats *)stats);
}

